import { type LinkProps as RouterLinkProps } from 'react-router-dom';
import { type ChakraLinkProps } from '.';
type LinkProps = Omit<ChakraLinkProps, 'href'> & RouterLinkProps;
/**
 * Themeable Link which wraps react-router's Link.
 *
 * ```tsx
 * <Link to="/">anchor text</Link>
 * ```
 *
 * Note: Our default usage pattern is to link to a client-side route using
 * react-router; in the case you want to link to an external URL, import
 * `<ChakraLink />` instead.
 *
 * ## FIXME
 *
 * When a consuming app imports this component, it throws the following error:
 *
 * > Cannot destructure property 'basename' of 'k.useContext(...)' as it is null.
 *
 * It seems this has to do with RouterLink requiring to be a child of RouterProvider,
 * which _should_ work like this, but doesn't... If this component is defined within
 * the consuming app, rather than the library, it works as expected.
 *
 * ## Workaround
 *
 * ```tsx
 * import { Link } from '@chakra-ui/react';
 * import { Link as RouterLink } from 'react-router-dom';
 *
 * <Link as={RouterLink} to="#">Anchor</Link>
 * ```
 *
 * @see https://reactrouter.com/en/main/components/link
 * @see https://chakra-ui.com/docs/components/link/usage#usage-with-routing-library
 */
export declare const Unsafe_Link: (props: LinkProps) => import("react/jsx-runtime").JSX.Element;
export {};
